@@ -537,24 +537,13 @@ TMulKS (listz_t b, unsigned int n, listz_t a, unsigned int m,
   free (ap);
 
 #ifdef DEBUG
-  fprintf (ECM_STDOUT, "%ums\n", elltime (st, cputime ()));
+  fprintf (ECM_STDOUT, "%ldms\n", elltime (st, cputime ()));
 #endif
   
  TMulKS_end:
   return ret;
 }
 
-#ifdef DEBUG
-void
-mpn_print (mp_ptr np, mp_size_t nn)
-{
-  mp_size_t i;
-  for (i = 0; i < nn; i++)
-    fprintf (ECM_STDOUT, "+%lu*B^%u", np[i], i);
-  fprintf (ECM_STDOUT, "\n");
-}
-#endif
-
 unsigned int
 ks_wrapmul_m (unsigned int m0, unsigned int k, mpz_t n)
 {
@@ -641,6 +630,7 @@ ks_wrapmul (listz_t R, unsigned int m0,
 #else
   ASSERT_ALWAYS(0); /* ks_wrapmul should not be called in that case */
 #endif
+  ASSERT(i % s == 0);
   m = i / s;
   ASSERT(m <= 2 * m0 - 3 + list_mul_mem (m0 - 1));
 
@@ -660,20 +650,20 @@ ks_wrapmul (listz_t R, unsigned int m0,
         free (t1_ptr);
         return 0;
       }
-#ifdef FFT_WRAP
     mpn_mulmod_bnm1 (t2_ptr, i, t0_ptr, size_t0, t1_ptr, size_t1, tp);
-#endif
+    if ((mp_size_t) i > size_t0 + size_t1)
+      MPN_ZERO(t2_ptr + size_t0 + size_t1, i - (size_t0 + size_t1));
     free (tp);
   }
-  
-  for (i = 0, tp = t2_ptr; i < m; i++, tp += s)
+
+  for (t = 0, tp = t2_ptr; t < m; t++, tp += s)
     {
       size_tmp = s;
       MPN_NORMALIZE(tp, size_tmp);
-      r_ptr = MPZ_REALLOC (R[i], size_tmp);
+      r_ptr = MPZ_REALLOC (R[t], size_tmp);
       if (size_tmp)
         MPN_COPY (r_ptr, tp, size_tmp);
-      SIZ(R[i]) = size_tmp;
+      SIZ(R[t]) = size_tmp;
     }
 
   free (t0_ptr);
